@@ -6,7 +6,8 @@
 #
 # Copyright (c), 2013-2025, John McNamara, jmcnamara@cpan.org
 #
-from ...workbook import Workbook
+from xlsxwriter.workbook import Workbook
+
 from ..excel_comparison_test import ExcelComparisonTest
 
 
@@ -17,16 +18,22 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-        self.set_filename("utf8_03.xlsx")
+        self.set_filename("utf8_05.xlsx")
+
+        self.ignore_files = [
+            "xl/calcChain.xml",
+            "[Content_Types].xml",
+            "xl/_rels/workbook.xml.rels",
+        ]
 
     def test_create_file(self):
         """Test the creation of an XlsxWriter file with utf-8 strings."""
 
         workbook = Workbook(self.got_filename)
 
-        worksheet = workbook.add_worksheet("Café")
+        worksheet = workbook.add_worksheet()
 
-        worksheet.write("A1", "Café")
+        worksheet.write_formula("A1", '="Café"', None, "Café")
 
         workbook.close()
 
